--- old/usr/src/lib/libm/common/Q/sincospil.c	2019-06-06 20:38:57.875396653 +0000
+++ new/usr/src/lib/libm/common/Q/sincospil.c	2019-06-06 20:38:57.894112847 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -71,34 +72,38 @@
 #include "libm.h"
 #include "longdouble.h"
 
-#define	I(q, m)	((int *) &(q))[m]
-#define	U(q, m)	((unsigned *) &(q))[m]
+#define	I(q, m)				((int *)&(q))[m]
+#define	U(q, m)				((unsigned *)&(q))[m]
 #if defined(__LITTLE_ENDIAN) || defined(__x86)
-#define	LDBL_MOST_SIGNIF_I(ld)	((I(ld, 2) << 16) | (0xffff & (I(ld, 1) >> 15)))
-#define	LDBL_LEAST_SIGNIF_U(ld)	U(ld, 0)
-#define	PREC	64
-#define	PRECM1	63
-#define	PRECM2	62
+#define	LDBL_MOST_SIGNIF_I(ld)		((I(ld, 2) << 16) | (0xffff & (I(ld, \
+	1) >> 15)))
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, 0)
+#define	PREC				64
+#define	PRECM1				63
+#define	PRECM2				62
+
 static const long double twoPRECM2 = 9.223372036854775808000000000000000e+18L;
 #else
-#define	LDBL_MOST_SIGNIF_I(ld)	I(ld, 0)
-#define	LDBL_LEAST_SIGNIF_U(ld)	U(ld, sizeof (long double) / sizeof (int) - 1)
-#define	PREC	113
-#define	PRECM1	112
-#define	PRECM2	111
+#define	LDBL_MOST_SIGNIF_I(ld)		I(ld, 0)
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, sizeof (long double) / \
+	sizeof (int) - 1)
+#define	PREC				113
+#define	PRECM1				112
+#define	PRECM2				111
+
 static const long double twoPRECM2 = 5.192296858534827628530496329220096e+33L;
 #endif
 
-static const long double
-zero	= 0.0L,
-quater	= 0.25L,
-one	= 1.0L,
-pi	= 3.141592653589793238462643383279502884197e+0000L,
-sqrth	= 0.707106781186547524400844362104849039284835937688474,
-tiny	= 1.0e-100;
+static const long double zero = 0.0L,
+	quater = 0.25L,
+	one = 1.0L,
+	pi = 3.141592653589793238462643383279502884197e+0000L,
+	sqrth = 0.707106781186547524400844362104849039284835937688474,
+	tiny = 1.0e-100;
 
 void
-sincospil(long double x, long double *s, long double *c) {
+sincospil(long double x, long double *s, long double *c)
+{
 	long double y, z, t;
 	int hx, n, k;
 	unsigned lx;
@@ -106,6 +111,7 @@
 	hx = LDBL_MOST_SIGNIF_I(x);
 	lx = LDBL_LEAST_SIGNIF_U(x);
 	k = ((hx & 0x7fff0000) >> 16) - 0x3fff;
+
 	if (k >= PRECM2) {		/* |x| >= 2**(Prec-2) */
 		if (k >= 16384) {
 			*s = *c = x - x;
@@ -129,64 +135,75 @@
 					*s = one;
 					*c = zero;
 				}
+
 				if ((lx & 2) != 0) {
 					*s = -*s;
 					*c = -*c;
 				}
 			}
 		}
-	} else if (k < -2) 	/* |x| < 0.25 */
+	} else if (k < -2) {		/* |x| < 0.25 */
 		*s = __k_sincosl(pi * fabsl(x), zero, c);
-	else {
+	} else {
 		/* y = |4x|, z = floor(y), and n = (int)(z mod 8.0) */
 		y = 4.0L * fabsl(x);
+
 		if (k < PRECM2) {
 			z = y + twoPRECM2;
 			n = LDBL_LEAST_SIGNIF_U(z) & 7;	/* 3 LSb of z */
 			t = z - twoPRECM2;
 			k = 0;
-			if (t == y)
+
+			if (t == y) {
 				k = 1;
-			else if (t > y) {
+			} else if (t > y) {
 				n -= 1;
 				t = quater + (y - t) * quater;
-			} else
+			} else {
 				t = (y - t) * quater;
-		} else { 	/* k = Prec-3 */
+			}
+		} else {				/* k = Prec-3 */
 			n = LDBL_LEAST_SIGNIF_U(y) & 7;	/* 3 LSb of z */
 			k = 1;
 		}
-		if (k) {	/* x = N/4 */
-			if ((n & 1) != 0)
+
+		if (k) {		/* x = N/4 */
+			if ((n & 1) != 0) {
 				*s = *c = sqrth + tiny;
-			else
-				if ((n & 2) == 0) {
-					*s = zero;
-					*c = one;
-				} else {
-					*s = one;
-					*c = zero;
-				}
+			} else if ((n & 2) == 0) {
+				*s = zero;
+				*c = one;
+			} else {
+				*s = one;
+				*c = zero;
+			}
+
 			if ((n & 4) != 0)
 				*s = -*s;
+
 			if (((n + 1) & 4) != 0)
 				*c = -*c;
 		} else {
 			if ((n & 1) != 0)
 				t = quater - t;
+
 			if (((n + (n & 1)) & 2) == 0)
 				*s = __k_sincosl(pi * t, zero, c);
 			else
 				*c = __k_sincosl(pi * t, zero, s);
+
 			if ((n & 4) != 0)
 				*s = -*s;
+
 			if (((n + 2) & 4) != 0)
 				*c = -*c;
 		}
 	}
+
 	if (hx < 0)
 		*s = -*s;
 }
+
 #undef U
 #undef LDBL_LEAST_SIGNIF_U
 #undef I
